@@ -94,7 +94,7 @@ class Service:
         if self._secret_arn is None:
             return []
         data = loads(client.get_secret_value(SecretId=self._secret_arn)["SecretString"])
-        return [dict(name=x, valueFrom=f"{self._secret_arn}:{x}") for x in data.keys()]
+        return [dict(name=x, valueFrom=f"{self._secret_arn}:{x}::") for x in data.keys()]
 
     @cache
     def get_load_balancers(self):
